@@ -7,6 +7,7 @@ from zex.sdk.data_types import CancelOrderRequest, OrderSide, PlaceOrderRequest
 from zex.sdk.websocket import ParsedWebSocketOrderMessage, ZexSocketManager
 
 
+@pytest.mark.skip
 @pytest.mark.asyncio
 async def test_given_valid_api_key_when_client_is_created_then_user_id_is_registered(
     zex_dev_api_key: str,
@@ -19,6 +20,7 @@ async def test_given_valid_api_key_when_client_is_created_then_user_id_is_regist
     assert client.user_id is not None
 
 
+@pytest.mark.skip
 @pytest.mark.asyncio
 async def test_given_registered_client_when_place_empty_order_list_then_nothing_is_submitted(
     zex_dev_api_key: str,
@@ -33,6 +35,7 @@ async def test_given_registered_client_when_place_empty_order_list_then_nothing_
     # No-op with no orders should not fail
 
 
+@pytest.mark.skip
 @pytest.mark.asyncio
 async def test_given_registered_client_when_cancel_empty_signed_order_list_then_nothing_is_cancelled(
     zex_dev_api_key: str,
@@ -61,6 +64,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # Regular BTC buy.
         pytest.param(
             "BTC",
@@ -71,6 +75,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # Regular BTC sell.
         pytest.param(
             "ETH",
@@ -81,6 +86,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # Regular ETH buy.
         pytest.param(
             "ETH",
@@ -91,6 +97,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # Regular ETH sell.
         pytest.param(
             "BTC",
@@ -101,6 +108,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # 5 decimal digit volume.
         pytest.param(
             "BTC",
@@ -111,6 +119,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # 6 Non-zero decimals.
         pytest.param(
             "BTC",
@@ -121,6 +130,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # 7 Non-zero decimals.
         pytest.param(
             "BTC",
@@ -131,6 +141,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # 8 Non-zero decimals.
         pytest.param(
             "BTC",
@@ -141,6 +152,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # 9 Non-zero decimals.
         pytest.param(
             "BTC",
@@ -151,6 +163,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # 10 Non-zero decimals.
         pytest.param(
             "ETH",
@@ -161,6 +174,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # Non-zero decimals ETH.
         pytest.param(
             "ETH",
@@ -171,6 +185,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # With leading zero.
         pytest.param(
             "BTC",
@@ -181,6 +196,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # Integer price.
         pytest.param(
             "BTC",
@@ -191,6 +207,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # Price with 2 digits.
         pytest.param(
             "BTC",
@@ -201,6 +218,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # Price Digits leading Zero.
         pytest.param(
             "BTC",
@@ -211,6 +229,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # Price with 4 digits.
         pytest.param(
             "BTC",
@@ -221,6 +240,7 @@ async def test_given_registered_client_when_cancel_empty_signed_order_list_then_
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),  # Price with small digits.
         # Main version.
         pytest.param(
@@ -431,6 +451,8 @@ async def test_given_registered_client_when_place_and_cancel_orders_then_feedbac
         side=side,
         volume=volume,
         price=price,
+        volume_precision=5,
+        price_precision=2,
     )
 
     updated_order_status = []
@@ -477,6 +499,7 @@ async def test_given_registered_client_when_place_and_cancel_orders_then_feedbac
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),
     ],
 )
@@ -495,6 +518,8 @@ async def test_given_a_batch_of_orders_when_place_and_cancel_then_feedbacks_shou
             side=OrderSide.BUY,
             volume=0.0001,
             price=30000,
+            volume_precision=5,
+            price_precision=2,
         ),
         PlaceOrderRequest(
             base_token="BTC",
@@ -502,6 +527,8 @@ async def test_given_a_batch_of_orders_when_place_and_cancel_then_feedbacks_shou
             side=OrderSide.BUY,
             volume=0.0001,
             price=31000,
+            volume_precision=5,
+            price_precision=2,
         ),
         PlaceOrderRequest(
             base_token="BTC",
@@ -509,6 +536,8 @@ async def test_given_a_batch_of_orders_when_place_and_cancel_then_feedbacks_shou
             side=OrderSide.BUY,
             volume=0.0001,
             price=32000,
+            volume_precision=5,
+            price_precision=2,
         ),
         PlaceOrderRequest(
             base_token="BTC",
@@ -516,6 +545,8 @@ async def test_given_a_batch_of_orders_when_place_and_cancel_then_feedbacks_shou
             side=OrderSide.BUY,
             volume=0.0001,
             price=33000,
+            volume_precision=5,
+            price_precision=2,
         ),
     ]
 
@@ -575,6 +606,7 @@ async def test_given_a_batch_of_orders_when_place_and_cancel_then_feedbacks_shou
             pytest.lazy_fixture("zex_dev_api_key"),  # type: ignore
             True,
             id="testnet",
+            marks=pytest.mark.skip(reason="Skipping the mainnet case for now."),
         ),
     ],
 )
@@ -593,6 +625,8 @@ async def test_given_a_batch_of_orders_when_placing_orders_then_order_data_shoul
             side=OrderSide.BUY,
             volume=0.0001,
             price=30000,
+            volume_precision=5,
+            price_precision=2,
         ),
         PlaceOrderRequest(
             base_token="BTC",
@@ -600,6 +634,8 @@ async def test_given_a_batch_of_orders_when_placing_orders_then_order_data_shoul
             side=OrderSide.BUY,
             volume=0.0001,
             price=31000,
+            volume_precision=5,
+            price_precision=2,
         ),
         PlaceOrderRequest(
             base_token="BTC",
@@ -607,6 +643,8 @@ async def test_given_a_batch_of_orders_when_placing_orders_then_order_data_shoul
             side=OrderSide.BUY,
             volume=0.0001,
             price=32000,
+            volume_precision=5,
+            price_precision=2,
         ),
         PlaceOrderRequest(
             base_token="BTC",
@@ -614,6 +652,8 @@ async def test_given_a_batch_of_orders_when_placing_orders_then_order_data_shoul
             side=OrderSide.BUY,
             volume=0.0001,
             price=33000,
+            volume_precision=5,
+            price_precision=2,
         ),
     ]
 
